<?php

/******************** YouTube Search in the admin ********************/

class TubeNinjaEditorButton {
    function TubeNinjaEditorButton() {
        if (is_admin() && current_user_can('edit_posts') &&
                        current_user_can('edit_pages') &&
                        get_user_option('rich_editing') == 'true' ) {   
                add_filter('tiny_mce_version', array(&$this,
                                'tiny_mce_version') );
                add_filter("mce_external_plugins", array(&$this,
                                "mce_external_plugins"));
                add_filter('mce_buttons', array(&$this, 'mce_buttons'));

                wp_enqueue_script('jquery');
                wp_enqueue_script('jquery-ui-widget');
                wp_enqueue_script('jquery-ui-dialog');
                wp_enqueue_script('jquery-ui-position');
                wp_enqueue_style('tn_ytsearch_css',
				 plugins_url(TN_PLUGIN_FOLDER.'/css/tn-ytsearch.css'));
        }
    }
    function mce_buttons($buttons) {
        array_push($buttons, "separator", "ytsearch");
        return $buttons;
    }
    function mce_external_plugins($plugin_array) {
        $plugin_array['ytsearch'] = plugins_url(
                                TN_PLUGIN_FOLDER . '/js/tn-ytsearch.js');
        return $plugin_array;
    }
    function tiny_mce_version($version) {
        return ++$version;
    }
}

add_action('init', 'tn_editor_button');
function tn_editor_button() {
   global $tn_editor_button;
   $tn_editor_button = new TubeNinjaEditorButton();
}

/******************* Saving YouTube videos as metadata ********************/

function tnyt_get_video_data($vid) {
    $url = "https://gdata.youtube.com/feeds/api/videos/$vid?v=2&alt=jsonc";
    $json = file_get_contents($url);
    return json_decode($json, true);
}

add_action('save_post', 'tnyt_save_post_meta');
function tnyt_save_post_meta($post_id) {
    if (!current_user_can('edit_post', $post_id) ||
                !array_key_exists('content', $_REQUEST) ||
                (get_post_status($post_id) != 'publish' &&
                        get_post_status($post_id) != 'post')) {
        return;
    }
    $content = $_REQUEST['content'];
    $matches = array();
    $vid_regexp = '[a-zA-Z0-9_-]+';
    $query_junk = "[^~!*()'\\[\\]]*";
    delete_post_meta($post_id, TN_YTVID_POST_META);
    if (preg_match_all(
                //'|(?:\[embed(?:\s+[^]]+)?\])?' .
                '#http://(?:www\.)?youtube\.com/watch\?' .
                $query_junk .  '(?<=[&?])v=(' . $vid_regexp . ')' . $query_junk . '#'
                //'(?:\[/embed\])?|'
                , $content, &$matches, PREG_PATTERN_ORDER)) {
        foreach ($matches[1] as $vid) {
            $vid_data = tnyt_get_video_data($vid);
            $meta = array($vid, $vid_data['data']['thumbnail']['sqDefault']);
            add_post_meta($post_id, TN_YTVID_POST_META, $meta, false);
        }
    }
}

function tnyt_get_random_videos($n=6) {
    global $wpdb;
    $table = $wpdb->prefix . 'postmeta';
    $mkey = TN_YTVID_POST_META;
    $sql = $wpdb->prepare(
            "select post_id, meta_value from $table where meta_key = %s", $mkey);
    $result = $wpdb->get_results($sql, ARRAY_A);
    $keys = array_rand($result, min($n, count($result)));
    $r = array();
    foreach ($keys as $idx) {
        $meta_val = unserialize($result[$idx]['meta_value']);
        $r[] = array_merge((array)$result[$idx]['post_id'], $meta_val);
    }
    return $r;
// too bad this is only for PHP 5.3:
//     return array_map(
//         function ($idx) use ($result) { return $result[$idx]; }, $keys);
}

/** ******************** Random YouTube video widget ***********************/
add_action('widgets_init', 'register_ytrandom');
function register_ytrandom() {
    register_widget('RandomYTWidget');
}

class RandomYTWidget extends WP_Widget {
    function RandomYTWidget() {
        $widget_ops = array('classname' => 'RandomYTWidget', 'description' => 'Displays a widget with random YouTube videos from posts' );
        $this->WP_Widget('RandomYTWidget', 'Random YouTube Videos', $widget_ops);
    }

    function form($instance) {
        $instance = wp_parse_args(
                (array)$instance, array('heading' => 'Random Videos',
                                        'width' => '240',
                                        'number' => '6'));
        $title = $instance['heading'];
        $width = $instance['width'];
        $number = $instance['number'];
        ?>
        <p>
        <label for="<?php echo $this->get_field_id('heading'); ?>">
            Title:
                <input
                    class="widefat"
                    id="<?php echo $this->get_field_id('heading'); ?>"
                    name="<?php echo $this->get_field_name('heading'); ?>"
                    type="text" value="<?php echo esc_attr($title); ?>" />
        </label>
        <label for="<?php echo $this->get_field_id('width'); ?>">
            Width of the sidebar (px):
                <input
                    class="widefat"
                    id="<?php echo $this->get_field_id('width'); ?>"
                    name="<?php echo $this->get_field_name('width'); ?>"
                    type="text" value="<?php echo esc_attr($width); ?>" />
        </label>
        <label for="<?php echo $this->get_field_id('number'); ?>">
            Number of videos:
                <input
                    class="widefat"
                    id="<?php echo $this->get_field_id('number'); ?>"
                    name="<?php echo $this->get_field_name('number'); ?>"
                    type="text" value="<?php echo esc_attr($number); ?>" />
        </label>
        </p>
        <?php
    }

    function update($new_instance, $old_instance) {
        $instance = $old_instance;
        $instance['heading'] = $new_instance['heading'];
        $instance['width'] = $new_instance['width'];
        $instance['number'] = $new_instance['number'];
        return $instance;
    }

    function widget($args, $instance) {
        extract($args, EXTR_SKIP);  

        echo $before_widget;
        $title = empty($instance['heading']) ?
	  ' ': $instance['heading']; //' ' : apply_filters('widget_title', $instance['title']);
        $width = empty($instance['width']) || !(int)$instance['width'] ?
                                240 : (int)$instance['width'];
        $number = empty($instance['number']) || !(int)$instance['number'] ?
                                6 : (int)$instance['number'];
        $default_width = 100; $default_height = 75;
        $items_per_row = ceil($width/$default_width);
        $item_width = floor(.9 * $width / $items_per_row);
        $item_height = round($default_height * $item_width/$default_width);

        if (!empty($title)) echo $before_title . $title . $after_title;

        $ytvids = tnyt_get_random_videos($number);
        echo '<ul style="list-style-type: none;">';
        foreach ($ytvids as $i => $ytvid) {
            if ($i % $items_per_row === 0) echo '<br />';
            $post = get_permalink($ytvid[0]);
            $title = get_the_title($ytvid[0]);
            $thumb = $ytvid[2];
            ?>
            <li style="float: left; margin: 5px; padding: 5px;">
                <a href="<?php echo $post; ?>">
                    <img src="<?php echo esc_html($thumb); ?>"
                         title="<?php echo esc_html($title); ?>"
                         style="width: <?php echo $item_width; ?>px; height: <?php echo $item_height; ?>px;" />
                </a>
            </li>
            <?php
        }
        echo '</ul>';

        echo $after_widget;
    }
}

// Disable related videos with youtube embedded videos
add_filter('oembed_result', 'tnyt_disable_related_videos', 10, 3);
function tnyt_disable_related_videos ($html, $url, $args) {
    if (isset($args['rel']) && 0 == $args['rel']) {
        return preg_replace('#src="([^"]+)"#', 'src="$1&rel=0"', $html);
    }
    return $html;
}