<?php

define('TN_THEME_PAGE_TITLE', 'WP Tube Ninja Theme');
define('TN_THEME_MENU_TITLE', 'WP Tube Ninja Theme');
define('TN_THEME_ADMIN_SLUG', 'tn-theme');

load_theme_textdomain('tn-theme', TEMPLATEPATH . '/languages');

$locale = get_locale();
$locale_file = TEMPLATEPATH . "/languages/$locale.php";
if (is_readable($locale_file)) require_once($locale_file);

// echo comment navigation
function tn_theme_comment_nav() {
    if (get_comment_pages_count() > 1 && get_option('page_comments')) {
    ?>
        <div id="comment-nav">
            <h1 class="assistive-text">
                <?php _e('Comment navigation', 'tn-theme' ); ?>
            </h1>
            <div class="nav-previous">
    <?php previous_comments_link(__('&larr; Older Comments', 'tn-theme')); ?>
            </div>
            <div class="nav-next">
    <?php next_comments_link(__('Newer Comments &rarr;', 'tn-theme')); ?>
            </div>
        </div>
    <?php
    }
}

// echo the page number
function page_number() {
    if (get_query_var('paged')) {
        echo ' | ' . __('Page', 'tn-theme') . ' ' . get_query_var('paged');
    }
}

function tn_theme_post_navigation($id) {
    global $wp_query;
    $total_pages = $wp_query->max_num_pages;
    if ($total_pages > 1) {
        ?>
        <div id="<?php echo esc_html($id); ?>" class="navigation">
            <div class="nav-previous">
                <?php next_posts_link(__('&laquo; Older posts', 'tn-theme')) ?>
            </div>
            <div class="nav-next">
                <?php previous_posts_link(__('Newer posts &raquo;',
                            'tn-theme')) ?>
            </div>
        </div><!-- #<?php echo $id ?> -->
        <?php
    }
}

function tn_theme_clear_sidebar($widget_area) {
    $active_widgets = get_option('sidebars_widgets');
    if (!isset($active_widgets[$widget_area])) return;
    foreach ($active_widgets[$widget_area] as $wid) {
        preg_match('/^(.*)-(\d+)$/', $wid, $m);
        $widget_type = $m[0]; $widget_counter = $m[1];
        $widgets = get_option("widget_$widget_type");
        unset($widgets[$widget_counter]);
        update_option("widget_$widget_type", $widgets);
    }
    $active_widgets[$widget_area] = array();
    update_option('sidebars_widgets', $active_widgets);
}

function tn_theme_add_widgets($widget_area, $widgets) {
    // $widgets is an array from widget types to args (one widget per type)
    // this function deletes all widgets that are already in $widget_area
    tn_theme_clear_sidebar($widget_area);
    $active_widgets = get_option('sidebars_widgets');
    if (!isset($active_widgets[$widget_area])) return;
    foreach ($widgets as $widget_type => $args) {
        $widget_list = get_option("widget_$widget_type");
        if (false === $widget_list) continue;
        $widget_list[] = $args;
        end($widget_list);
        $counter = key($widget_list);
        $active_widgets[$widget_area][] = "$widget_type-$counter";
        update_option("widget_$widget_type", $widget_list);
    }
    update_option('sidebars_widgets', $active_widgets);
// echo 'now $active widgets is ';print_r($active_widgets);exit;
}

add_action('update_option_sidebars_widgets',
           'tn_theme_add_default_widgets', 10, 2);
function tn_theme_add_default_widgets($old, $new) {
    add_option('tn_theme_add_default_widgets', 'yes');
    if ('no' === get_option('tn_theme_add_default_widgets')) return;

    global $wp_widget_factory;
    $url = 'http://www.wptubeninja.com/';
    $name = 'WP Tube Ninja';
    $randomyt_registered = array_key_exists(
                    'RandomYTWidget', $wp_widget_factory->widgets);
    $widgets =  array(
        'widget-area' => array_merge(
            array('search' => array('title' => ''),
                  'recent-posts' => array('title' => '', 'number' => 10),
                  // 'recent-comments' => array('title' => '', 'number' => 5)
            ),
            $randomyt_registered ?
                array('randomytwidget' => array(
                  'title' => 'Random Videos', 'width' => 240, 'number' => 6))
                : array(),
            array('categories' => array('title' => '', 'count' => 0,
                                        'hierarchical' => 0, 'dropdown' => 0),
                  'archives' => array('title' => '', 'count' => 0,
                                      'dropdown' => 0))),
        'bottom-widget-area' => array(
            'text' => array('title' => '',
                  'text' => "Powered by <a href=\"$url\">$name</a>"))
    );

    foreach ($widgets as $widget_area => $widget_list) {
        if (!isset($new[$widget_area])) {
                continue;
        }
        update_option('tn_theme_add_default_widgets', 'no');
        tn_theme_add_widgets($widget_area, $widget_list);
    }
    update_option('default_comment_status', 'open');
    update_option('comment_registration', '0');
}

add_action('wp_enqueue_scripts', 'tn_theme_custom_scripts');
function tn_theme_custom_scripts() {
    if (!is_active_sidebar('widget-area')) {
        ?><style type="text/css">
        #center-main-content {width: 100%;}
        </style><?php
    }
}

add_action('widgets_init', 'tn_theme_widgets_init');
function tn_theme_widgets_init() {
    $before_widget = '<li id="%1$s" class="widget-container %2$s">';
    $after_widget = '</li>';
    $before_title = '<h3 class="widget-title">';
    $after_title = '</h3>';
    register_sidebar(array(
        'name' => __('Side Widget Area', 'tn-theme'),
        'id' => 'widget-area', 'tn-theme',
        'before_widget' => $before_widget,
        'after_widget' => $after_widget,
        'before_title' => $before_title,
        'after_title' => $after_title
    ));
    register_sidebar(array(
        'name' => __('Footer Widget Area', 'tn-theme'),
        'id' => 'bottom-widget-area',
        'before_widget' => $before_widget,
        'after_widget' => $after_widget,
        'before_title' => $before_title,
        'after_title' => $after_title
    ));
}

add_action('init', 'tn_theme_register_my_menus' );
function tn_theme_register_my_menus() {
    register_nav_menus(
        array('header-menu' => __('Header Menu', 'tn-theme'))
    );
    add_option('tn_theme_logo_url',
                    get_template_directory_uri().'/img/header.jpg');
}

/** Admin menu **/

add_action('admin_menu', 'tn_theme_setup_admin_menu');
function tn_theme_setup_admin_menu() {
    add_theme_page(
        TN_THEME_PAGE_TITLE,
        TN_THEME_MENU_TITLE,
        'edit_dashboard',
        TN_THEME_ADMIN_SLUG,
        'tn_theme_admin_menu'
    );
}

function tn_theme_admin_menu() {
    ?>
    <div class="wrap">
    <h2><?php _e('Theme settings', 'tn-theme'); ?></h2>
    <form method="post" action="options.php"><?php
        settings_fields(TN_THEME_ADMIN_SLUG.'_group');
        do_settings_sections(TN_THEME_ADMIN_SLUG);
        submit_button();
    ?>
    </form>
    </div>
    <?php
}

function tn_theme_admin_scripts() {
    wp_enqueue_script('media-upload');
    wp_enqueue_script('thickbox');
    wp_register_script('tn-theme-upload',
        get_bloginfo('template_directory').'/tn-logo-upload.js',
        array('jquery','media-upload','thickbox'));
    wp_enqueue_script('tn-theme-upload');
}

function tn_theme_admin_styles() {
    wp_enqueue_style('thickbox');
}

if (isset($_GET['page']) && $_GET['page'] == TN_THEME_ADMIN_SLUG) {
    add_action('admin_print_scripts', 'tn_theme_admin_scripts');
    add_action('admin_print_styles', 'tn_theme_admin_styles');
}

// call register settings function
add_action('admin_init', 'tn_theme_register_settings');
function tn_theme_register_settings() {
    register_setting(
            TN_THEME_ADMIN_SLUG.'_group',
            'tn_theme_logo_url',
            'tn_theme_settings_validate'
    );
    // general settings
    add_settings_section(
            'tn_theme_general',                 // ID
            '', //'General settings',           // title
            'tn_theme_settings_section_text',   // callback
            TN_THEME_ADMIN_SLUG                 // page
    );
    add_settings_field(
            'tn-theme-logo_url',        // ID
            __('Header', 'tn-theme'), // title
            'tn_theme_option_input',    // callback
            TN_THEME_ADMIN_SLUG,        // page
            'tn_theme_general'          // section
    );
}

function tn_theme_settings_section_text() {
    // echo '<p>TN Theme Settings</p>';
}

function tn_theme_option_input() {
    $url = get_option('tn_theme_logo_url');
    ?>
    <input id="tn_theme_logo_url" type="text" size="36" name="tn_theme_logo_url" value="<?php
        echo $url; ?>" />
    <input id="tn_theme_upload_image_button"
            type="button"
            value="<?php _e('Upload Header', 'tn-theme'); ?>" />
    <?php /*
    <input id="tn_theme_reset_default_logo"
            type="button"
            value="<?php _e('Reset to default', 'tn-theme'); ?>" />
    <input id="tn_theme_default_logo_url"
            type="hidden" style="display: none;"
            value="<?php
                echo esc_html(get_template_directory_uri().'/img/header.jpg');
            ?>" /> */ ?>
    <br />Enter a URL or upload an image for the header (width 900 pixels).
    <?php
}

function tn_theme_settings_validate($input) {
    $oldval = get_option('tn_theme_logo_url');
    if (!preg_match('/^https?:\/\/[a-zA-Z0-9][a-zA-Z0-9.]*[a-zA-Z0-9]/',
            $input)) {
        tn_theme_bad_url_notice();
        return $oldval;
    }
    return $input;
}

function tn_theme_bad_url_notice() {
    ?>
    <div class="error">
            <p><?php _e('Invalid URL.', 'tn-theme'); ?></p>
    </div>
    <?php
}
